==> ews-javascript-api-0.1.3.tgz: package/js/PropertyDefinitions/ResponseObjectsPropertyDefinition.js <==
var __extends = this.__extends || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    __.prototype = b.prototype;
    d.prototype = new __();
};
var ResponseActions_1 = require("../Enumerations/ResponseActions");
var XmlElementNames_1 = require("../Core/XmlElementNames");
var ExtensionMethods_1 = require("../ExtensionMethods");
var PropertyDefinition_1 = require("./PropertyDefinition");
var ResponseObjectsPropertyDefinition = (function (_super) {
    __extends(ResponseObjectsPropertyDefinition, _super);
    function ResponseObjectsPropertyDefinition() {
        _super.apply(this, arguments);
    }
    ResponseObjectsPropertyDefinition.GetResponseAction = function (responseActionString) {
        var value = ResponseActions_1.ResponseActions.None;
        switch (responseActionString) {
            case XmlElementNames_1.XmlElementNames.AcceptItem:
                value = ResponseActions_1.ResponseActions.Accept;
                break;
            case XmlElementNames_1.XmlElementNames.TentativelyAcceptItem:
                value = ResponseActions_1.ResponseActions.TentativelyAccept;
                break;
            case XmlElementNames_1.XmlElementNames.DeclineItem:
                value = ResponseActions_1.ResponseActions.Decline;
                break;
            case XmlElementNames_1.XmlElementNames.ReplyToItem:
                value = ResponseActions_1.ResponseActions.Reply;
                break;
            case XmlElementNames_1.XmlElementNames.ForwardItem:
                value = ResponseActions_1.ResponseActions.Forward;
                break;
            case XmlElementNames_1.XmlElementNames.ReplyAllToItem:
                value = ResponseActions_1.ResponseActions.ReplyAll;
                break;
            case XmlElementNames_1.XmlElementNames.CancelCalendarItem:
                value = ResponseActions_1.ResponseActions.Cancel;
                break;
            case XmlElementNames_1.XmlElementNames.RemoveItem:
                value = ResponseActions_1.ResponseActions.RemoveFromCalendar;
                break;
            case XmlElementNames_1.XmlElementNames.SuppressReadReceipt:
                value = ResponseActions_1.ResponseActions.SuppressReadReceipt;
                break;
            case XmlElementNames_1.XmlElementNames.PostReplyItem:
                value = ResponseActions_1.ResponseActions.PostReply;
                break;
        }
        return value;
    };
    ResponseObjectsPropertyDefinition.prototype.LoadPropertyValueFromJson = function (value, service, propertyBag) { throw new Error("ResponseObjectsPropertyDefinition.ts - LoadPropertyValueFromJson : Not implemented."); };
    ResponseObjectsPropertyDefinition.prototype.LoadPropertyValueFromXmlJsObject = function (jsonObject, service, propertyBag) {
        debugger; //todo: validate
        var responseActionValue = ResponseActions_1.ResponseActions.None;
        var jsonResponseActions = jsonObject; // as object[];
        debugger; //check for missing aray 
        if (jsonResponseActions != null) {
            for (var _i = 0; _i < jsonResponseActions.length; _i++) {
                var jsonResponseAction = jsonResponseActions[_i];
                if (jsonResponseAction.__type) {
                    var actionString = jsonResponseAction.__type;
                    if (!ExtensionMethods_1.StringHelper.IsNullOrEmpty(actionString)) {
                        responseActionValue |= ResponseObjectsPropertyDefinition.GetResponseAction(actionString);
                    }
                }
            }
        }
        propertyBag._setItem(this, responseActionValue);
    };
    ResponseObjectsPropertyDefinition.prototype.WriteJsonValue = function (jsonObject, propertyBag, service, isUpdateOperation) { };
    ResponseObjectsPropertyDefinition.prototype.WritePropertyValueToXml = function (writer, propertyBag, isUpdateOperation) { };
    return ResponseObjectsPropertyDefinition;
})(PropertyDefinition_1.PropertyDefinition);
exports.ResponseObjectsPropertyDefinition = ResponseObjectsPropertyDefinition;

==> ews-javascript-api-0.1.6.tgz: package/js/PropertyDefinitions/ResponseObjectsPropertyDefinition.js <==
var __extends = this.__extends || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    __.prototype = b.prototype;
    d.prototype = new __();
};
var ResponseActions_1 = require("../Enumerations/ResponseActions");
var XmlElementNames_1 = require("../Core/XmlElementNames");
var ExtensionMethods_1 = require("../ExtensionMethods");
var PropertyDefinition_1 = require("./PropertyDefinition");
var ResponseObjectsPropertyDefinition = (function (_super) {
    __extends(ResponseObjectsPropertyDefinition, _super);
    function ResponseObjectsPropertyDefinition() {
        _super.apply(this, arguments);
    }
    ResponseObjectsPropertyDefinition.GetResponseAction = function (responseActionString) {
        var value = ResponseActions_1.ResponseActions.None;
        switch (responseActionString) {
            case XmlElementNames_1.XmlElementNames.AcceptItem:
                value = ResponseActions_1.ResponseActions.Accept;
                break;
            case XmlElementNames_1.XmlElementNames.TentativelyAcceptItem:
                value = ResponseActions_1.ResponseActions.TentativelyAccept;
                break;
            case XmlElementNames_1.XmlElementNames.DeclineItem:
                value = ResponseActions_1.ResponseActions.Decline;
                break;
            case XmlElementNames_1.XmlElementNames.ReplyToItem:
                value = ResponseActions_1.ResponseActions.Reply;
                break;
            case XmlElementNames_1.XmlElementNames.ForwardItem:
                value = ResponseActions_1.ResponseActions.Forward;
                break;
            case XmlElementNames_1.XmlElementNames.ReplyAllToItem:
                value = ResponseActions_1.ResponseActions.ReplyAll;
                break;
            case XmlElementNames_1.XmlElementNames.CancelCalendarItem:
                value = ResponseActions_1.ResponseActions.Cancel;
                break;
            case XmlElementNames_1.XmlElementNames.RemoveItem:
                value = ResponseActions_1.ResponseActions.RemoveFromCalendar;
                break;
            case XmlElementNames_1.XmlElementNames.SuppressReadReceipt:
                value = ResponseActions_1.ResponseActions.SuppressReadReceipt;
                break;
            case XmlElementNames_1.XmlElementNames.PostReplyItem:
                value = ResponseActions_1.ResponseActions.PostReply;
                break;
        }
        return value;
    };
    ResponseObjectsPropertyDefinition.prototype.LoadPropertyValueFromJson = function (value, service, propertyBag) { throw new Error("ResponseObjectsPropertyDefinition.ts - LoadPropertyValueFromJson : Not implemented."); };
    ResponseObjectsPropertyDefinition.prototype.LoadPropertyValueFromXmlJsObject = function (jsonObject, service, propertyBag) {
        //debug: //todo: validate
        var responseActionValue = ResponseActions_1.ResponseActions.None;
        var jsonResponseActions = jsonObject; // as object[];
        //debug: //ref: check for missing aray 
        if (jsonResponseActions != null) {
            for (var _i = 0; _i < jsonResponseActions.length; _i++) {
                var jsonResponseAction = jsonResponseActions[_i];
                if (jsonResponseAction.__type) {
                    var actionString = jsonResponseAction.__type;
                    if (!ExtensionMethods_1.StringHelper.IsNullOrEmpty(actionString)) {
                        responseActionValue |= ResponseObjectsPropertyDefinition.GetResponseAction(actionString);
                    }
                }
            }
        }
        propertyBag._setItem(this, responseActionValue);
    };
    ResponseObjectsPropertyDefinition.prototype.WriteJsonValue = function (jsonObject, propertyBag, service, isUpdateOperation) { };
    ResponseObjectsPropertyDefinition.prototype.WritePropertyValueToXml = function (writer, propertyBag, isUpdateOperation) { };
    return ResponseObjectsPropertyDefinition;
})(PropertyDefinition_1.PropertyDefinition);
exports.ResponseObjectsPropertyDefinition = ResponseObjectsPropertyDefinition;
